NativeSqliteOpenFactory class base

SqliteOpenFactory implementation for native platforms.

This class can be extended to customize how databases are opened on native platforms.

Inheritance

Constructors

NativeSqliteOpenFactory({required String path, SqliteOptions sqliteOptions = const SqliteOptions()})

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqliteOptions SqliteOptions
finalinherited

Methods

configureConnection(Database database, SqliteOpenOptions options) → void
Runs pragmaStatements for a freshly opened connection,
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openNativeConnection(SqliteOpenOptions options) → Database
Opens a new native Database connection and runs pragma statements via configureConnection.
pragmaStatements(SqliteOpenOptions options) List<String>
Pragma statements to run on newly opened connections to configure them.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited