An asynchronous mutex.
Constructors
- Mutex.simple()
-
Creates a simple mutex instance that can't be shared between tabs or
isolates.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
lock<
T> (Future< T> callback(), {Future<void> ? abortTrigger}) → Future<T> -
Runs
callbackin a critical section. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited