SqliteOpenOptions class final

Constructors

SqliteOpenOptions({required bool primaryConnection, required bool readOnly, String? debugName})
const

Properties

debugName String?
Name used in debug logs
final
hashCode int
The hash code for this object.
no setterinherited
openMode → OpenMode
no setter
primaryConnection bool
Whether this is the primary write connection for the database.
final
readOnly bool
Whether this connection is read-only.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited