flush abstract method

Future<void> flush()

Flush changes to the underlying storage.

In older versions of the sqlite3 package, writes on IndexedDB databases used to be asynchronous and might not complete if a tab writing to a database was closed shortly after making its write.

This is no longer an issue, recent versions persist changes in an IndexedDB transaction before the transaction completes. Thus, this method is deprecated and should not be used anymore.

Implementation

@_deprecatedFlush
Future<void> flush();