WebSqliteOpenFactory class base

SqliteOpenFactory implementation for the web.

This class can be extended to customize how databases are opened on the web.

Inheritance

Constructors

WebSqliteOpenFactory({required String path, SqliteOptions sqliteOptions = const SqliteOptions()})

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqliteOptions SqliteOptions
finalinherited

Methods

connectToWorker(WebSqlite sqlite, String name) Future<ConnectToRecommendedResult>
Uses WebSqlite to connects to the recommended database setup for name.
handleCustomRequest(JSAny? request) Future<JSAny?>
Handles a custom request sent from the worker to the client.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openConnection(SqliteOpenOptions options) Future<WebDatabase>
Currently this only uses the SQLite Web WASM implementation. This provides built in async Web worker functionality and automatic persistence storage selection. Due to being asynchronous, the under laying CommonDatabase is not accessible
openWebSqlite(WebSqliteOptions options) Future<WebSqlite>
Opens a WebSqlite instance for the given options.
pragmaStatements(SqliteOpenOptions options) List<String>
Pragma statements to run on newly opened connections to configure them.
override
toString() String
A string representation of this object.
inherited
updatesFor(Database database) Stream<UpdateNotification>
Obtains a stream of UpdateNotifications from a database.

Operators

operator ==(Object other) bool
The equality operator.
inherited