pragmaStatements method
Pragma statements to run on newly opened connections to configure them.
On native platforms, these configure WAL mode for instance. This can also be useed to configure an encryption key if SQLite3MultipleCiphers is used.
Implementation
@override
List<String> pragmaStatements(SqliteOpenOptions options) {
// WAL mode is not supported on Web
return [];
}